import QtQuick 2.3
import SAMBA 3.9
import SAMBA.Connection.Serial 3.9
import SAMBA.Device.SAMA7D65 3.9
import SAMBA.Applet 3.9

Item {
	property var nb_connection: 0
	property var bcp_config
	property var usage_displayed: false

	Component.onCompleted: {
		if (Script.arguments.length === 1 && Script.arguments[0] !== "help") {
			bcp_config = Script.arguments[0]
			nb_connection = 0
		}
		else {
			usage_displayed = true
			Utils.logInfo("USAGE:")
			Utils.logInfo(" To configure a Boot Configuration Packet:in OTP emulation mode:")
			Utils.logInfo("      sam-ba -x bcp-emul-usb.qml <boot_config_text>")
			Utils.logInfo(" Example:")
			Utils.logInfo("      sam-ba -x bcp-emul-usb.qml FLEXCOM3_USART_IOSET5,NFC_IOSET1_PMECC0xc2605007")
		}
	}

	SerialConnection {

		device: SAMA7D65CURIOSITY {
		}

		onConnectionOpened: {
			if (usage_displayed === true)
				return

			if (nb_connection === 0) {
				Utils.logUserInfo("First serial connection opened")
				nb_connection = 1

				Utils.logUserInfo(" - Configure EMULATION MODE in BSC_CR register")
				// initialize bootconfig flash applet
				initializeApplet("bootconfig")

				// Configure EMULATION MODE in BSC_CR register
				applet.writeBootCfg(BootCfgOTPC.BSCR, BSCR.fromText("EMULATION_ENABLED"))

				Utils.logUserInfo(" - Reset Emulation RAM")
				// Reset emulation
				applet.resetEmulSRAM()

				Utils.logUserInfo(" - Reset the device")
				// Reset the device
				initializeApplet("reset")

				this.close()
				Utils.sleep(1)
				this.open()
			}
			else if (nb_connection === 1) {
				Utils.logUserInfo("Second serial connection opened")
				Utils.logUserInfo(" - Write a bootconfig packet:" + bcp_config)

				initializeApplet("bootconfig")
				applet.writeBootCfg(BootCfgOTPC.BCP_EMUL, BCP.fromText(bcp_config))

				// Reset the device
				initializeApplet("reset")
			}
		}

		onConnectionClosed: {
			Utils.logInfo("=== Serial connection closed ===")
		}
	}
}
